# Training

Basic command:
```bash
combo --mode train \
      --training_data_path your_training_path \
      --validation_data_path your_validation_path
```

Options:
```bash
combo --helpfull
```

Examples (for clarity without training/validation data paths):

* train on gpu 0

    ```bash
    combo --mode train --cuda_device 0
    ```

* use pretrained embeddings:

    ```bash
    combo --mode train --pretrained_tokens your_pretrained_embeddings_path --embedding_dim your_embeddings_dim
    ```

* use pretrained transformer embeddings:

    ```bash
    combo --mode train --pretrained_transformer_name your_choosen_pretrained_transformer
    ```

* train only a dependency parser:

    ```bash
    combo --mode train --targets head,deprel
    ```

* use additional features (e.g. part-of-speech tags) for training a dependency parser (`token` and `char` are default features)

    ```bash
    combo --mode train --targets head,deprel --features token,char,upostag
    ```

## Enhanced UD

Training a model with Enhanced UD prediction **requires** data pre-processing.

```bash
combo --mode train \
      --training_data_path your_preprocessed_training_path \
      --validation_data_path your_preprocessed_validation_path \
      --targets feats,upostag,xpostag,head,deprel,lemma,deps \
      --config_path config.graph.template.jsonnet
```
### Data pre-processing
Download data from [IWPT20 Shared Task](https://universaldependencies.org/iwpt20/data.html).
It contains `enhanced_collapse_empty_nodes.pl` script which is required as pre-processing step.
Apply this script to training and validation data.

```bash
perl enhanced_collapse_empty_nodes.pl training.conllu > training.fixed.conllu
``` 

## Configuration

### Advanced
Config template [config.template.jsonnet](config.template.jsonnet) is formed in `allennlp` format so you can freely modify it.
There is configuration for all the training/model parameters (learning rates, epochs number etc.).
Some of them use `jsonnet` syntax to get values from configuration flags, however most of them can be modified directly there.